@@ -2,7 +2,7 @@
  * GChemPaint library
  * window.cc
  *
- * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -205,6 +205,11 @@ static void on_mail (GtkWidget *widget, gcp::Window* Win)
 	Win->GetApplication ()->OnMail ("mailto:gchempaint-main@nongnu.org");
 }
 
+static void on_live_assistance (GtkWidget *widget, gcp::Window *Win)
+{
+	Win->GetApplication ()->OnLiveAssistance ();
+}
+
 static void on_bug (GtkWidget *widget, gcp::Window* Win)
 {
 	Win->GetApplication ()->OnBug ();
@@ -341,6 +346,8 @@ static GtkActionEntry entries[] = {
 		  N_("View help for GChemPaint"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("GChemPaint on the _web"), NULL,
 		  N_("Browse GChemPaint's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about GChemPaint"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -411,9 +418,10 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
@@ -426,31 +434,6 @@ static const char *ui_description =
 "  </toolbar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
 using namespace gcu;
 
 namespace gcp {
@@ -465,7 +448,6 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
 	GtkAccelGroup *accel_group;
 	GError *error;
 
-	m_App = App;
 	SetWindow (window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL)));
 	g_object_set (G_OBJECT (window), "urgency-hint", false, NULL);
 	g_object_set_data (G_OBJECT (window), "gcp-role", (void*) 1);
@@ -492,14 +474,6 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	if (App->HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (m_UIManager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (App->HasMailAgent () && !gtk_ui_manager_add_ui_from_string (m_UIManager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
 	if (extra_ui && !gtk_ui_manager_add_ui_from_string (m_UIManager, extra_ui, -1, &error)) {
 		g_message ("building menus failed: %s", error->message);
 		g_error_free (error);
@@ -513,6 +487,7 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui):
 
 	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/FileMenu/Open");
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
+	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
 	gtk_recent_filter_add_mime_type (filter, "application/x-gchempaint");
 	gtk_recent_filter_add_mime_type (filter, "chemical/x-chemdraw");
@@ -565,7 +540,7 @@ Window::~Window ()
 
 void Window::OnFileNew()
 {
-	m_App->OnFileNew ();
+	m_Application->OnFileNew ();
 }
 
 void Window::OnSave()
@@ -573,12 +548,12 @@ void Window::OnSave()
 	if (m_Document->GetFileName ())
 		m_Document->Save();
 	else
-		m_App->OnSaveAs ();
+		m_Application->OnSaveAs ();
 }
 
 void Window::OnFileOpen()
 {
-	FileChooser (m_App, false, m_App->GetSupportedMimeTypes (), (!m_Document->HasChildren () && !m_Document->GetDirty ())? m_Document: NULL);
+	FileChooser (m_Application, false, m_Application->GetSupportedMimeTypes (), (!m_Document->HasChildren () && !m_Document->GetDirty ())? m_Document: NULL);
 }
 
 void Window::OnProperties()
@@ -748,7 +723,7 @@ bool Window::VerifySaved ()
 
 void Window::OnPageSetup ()
 {
-	new PrintSetupDlg (m_App, m_Document);
+	new PrintSetupDlg (m_Application, m_Document);
 }
 
 } // namespace gcp
