@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/application.h
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -37,6 +37,7 @@
 #include <gtk/gtkrecentmanager.h>
 #include <gcu/macros.h>
 
+/*!\file*/
 namespace gcu {
 
 class Document;
@@ -64,6 +65,9 @@ The datadir variable is used to build the full path to the help file:
 "file://"+datadir+"/gnome/help/"+name+"/"+LANG+"/"+name".xml".
 */
 	Application (std::string name, std::string datadir = DATADIR, char const *help_name = NULL, char const *icon_name = NULL);
+/*!
+The destructor.
+*/
 	virtual ~Application ();
 
 /*!
@@ -151,14 +155,9 @@ Creates a new empty message using the default mail if any.
 	void OnMail (char const *MailAddress = "mailto:gchemutils-main@nongnu.org");
 
 /*!
-@return true if the default mail agent is known, false otherwise.
+Attempts to open the \#gchemutils channel at irc.gimp.net.
 */
-	bool HasMailAgent () {return MailAgent.length () > 0;}
-
-/*!
-@return true if the default web browser is known, false otherwise.
-*/
-	bool HasWebBrowser () {return WebBrowser.length () > 0;}
+	void OnLiveAssistance ();
 
 /*!
 @return a GtkWidget for managing pixmap resolution when saving as image. This widget is
@@ -187,10 +186,41 @@ A default extension is appended to filename if none is detected.
 is not supported by GdkPixbuf.
 */
 	char const *GetPixbufTypeName (std::string& filename, char const *mime_type);
+
+/*!
+@param uri the uri of the document to load.
+@param mime_type the mime type of the document.
+@param Doc the document instance which will contain the loaded data.
+
+This method loads a document using the appropriate gcu::Loader class
+instance.
+@return true if no error occurred.
+*/
 	bool Load (std::string const &uri, const gchar *mime_type, Document* Doc);
+
+/*!
+@param uri the uri to which the document should be saved.
+@param mime_type the mime type of the document.
+@param Doc the document instance which contains the data to be saved.
+
+This method saves the document using the appropriate gcu::Loader class
+instance.
+@return true if no error occurred.
+*/
 	bool Save (std::string const &uri, const gchar *mime_type, Document* Doc);
+
+/*!
+Virtual method used to create documents. Default behavior does nothing and returns NULL.
+@return the newly created document or NULL.
+*/
 	virtual Document *CreateNewDocument () {return NULL;}
+
 #ifdef HAVE_GO_CONF_SYNC
+
+/*!
+Method used to retrieve the base configuration node.
+@return the base configuration node.
+*/
 	static GOConfNode *GetConfDir ();
 #endif
 
@@ -213,8 +243,6 @@ private:
 	std::string HelpBrowser;
 	std::string HelpFilename;
 	std::string CurDir;
-	std::string WebBrowser;
-	std::string MailAgent;
 #ifdef HAVE_GO_CONF_SYNC
 	static GOConfNode *m_ConfDir;
 #endif
@@ -238,6 +266,7 @@ GCU_PROT_PROP (std::set <Document*>, Docs)
 GCU_RO_PROP (unsigned, ScreenResolution)
 /*!\fn SetImageResolution(unsigned ImageResolution)
 @param ImageResolution the new image resolution.
+
 Sets the image resolution used when exporting a pixmap.
 Applications can use either the image resolution or the width and height to select
 an exported image size, but not both.
@@ -251,6 +280,7 @@ an exported image size, but not both.
 GCU_PROP (unsigned, ImageResolution)
 /*!\fn SetImageWidth(unsigned Width)
 @param Width the new image width.
+
 Sets the image width used when exporting a pixmap.
 Applications can use either the image resolution or the width and height to select
 an exported image size, but not both.
@@ -264,6 +294,7 @@ an exported image size, but not both.
 GCU_PROP (unsigned, ImageWidth)
 /*!\fn SetImageHeight(unsigned Height)
 @param Height the new image height.
+
 Sets the image height used when exporting a pixmap.
 Applications can use either the image resolution or the width and height to select
 an exported image size, but not both.
