@@ -66,14 +66,14 @@ public:
 	void SetFileName(const std::string &filename);
 	gchar* GetTitle() {return m_title;}
 	void SetTitle(const gchar* title);
-	void Save ();
+	void Save () const;
 	bool Load (const std::string &filename);
 #ifdef HAVE_OPENBABEL_2_2
 	bool Import (const std::string &filename, const std::string& mime_type);
 #endif
 	void ParseXMLTree(xmlNode* xml);
 	void OnNewDocument();
-	void OnExportVRML (const std::string &FileName);
+	void OnExportVRML (const std::string &FileName) const;
 	gcView* GetNewView();
 	void AddView(gcView* pView);
 	bool RemoveView(gcView* pView);
@@ -85,16 +85,22 @@ public:
 	virtual CrystalAtom* CreateNewAtom();
 	virtual CrystalLine* CreateNewLine();
 	virtual CrystalCleavage* CreateNewCleavage();
-	virtual const char* GetProgramId();
+	virtual const char* GetProgramId() const;
 	void SetActiveView (gcView *pView) {m_pActiveView = pView;}
 	void SaveAsImage (const std::string &filename, char const *type, std::map<std::string, std::string>& options);
 	gcView *GetActiveView () {return m_pActiveView;}
 	virtual bool LoadNewView (xmlNodePtr node);
 	std::list <CrystalView *> *GetViews () {return &m_Views;}
 	void RenameViews ();
+	void SetAuthor (char const *author);
+	void SetMail (char const *mail);
+	void SetComment (char const *comment);
+	void SetLabel (char const *label);
+	GDate *GetCreationDate () {return &m_CreationDate;}
+	GDate *GetRevisionDate () {return &m_RevisionDate;}
 
 private:
-	void Error(int num);
+	void Error(int num) const;
 	
 	//Implementation
 private:
@@ -103,8 +109,13 @@ private:
 	GtkWidget* m_widget;
 	std::list <gcu::Dialog *> m_Dialogs;
 	gcView *m_pActiveView;
+	GDate m_CreationDate, m_RevisionDate;
 
-GCU_RO_PROP (bool, ReadOnly);
+GCU_RO_PROP (bool, ReadOnly)
+GCU_RO_PROP (char *, Label)
+GCU_RO_PROP (char *, Author)
+GCU_RO_PROP (char *, Mail)
+GCU_RO_PROP (char *, Comment)
 };
 
 #endif //GCRYSTAL_DOCUMENT_H
