@@ -26,7 +26,6 @@
 #define GCRYSTAL_VIEW_H
 
 #include <libxml/parser.h>
-#include <libgnomeprint/gnome-print.h>
 #include <list>
 #include <gcu/crystalview.h>
 #include <gcu/matrix.h>
@@ -39,7 +38,7 @@ class gcWindow;
 
 using namespace gcu;
 
-class gcView: public CrystalView, public DialogOwner
+class gcView: public CrystalView
 {
 public:
 	gcView (gcDocument *pDoc);
